@@ -8,7 +8,9 @@ import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.io.File;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
+import java.util.Locale;
 
 import javax.swing.AbstractListModel;
 import javax.swing.ComboBoxModel;
@@ -32,14 +34,19 @@ import net.sf.openrocket.communication.UpdateInfo;
 import net.sf.openrocket.communication.UpdateInfoRetriever;
 import net.sf.openrocket.gui.components.DescriptionArea;
 import net.sf.openrocket.gui.components.StyledLabel;
+import net.sf.openrocket.gui.components.StyledLabel.Style;
 import net.sf.openrocket.gui.dialogs.UpdateInfoDialog;
-import net.sf.openrocket.gui.main.SimpleFileFilter;
+import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.logging.LogHelper;
 import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.unit.Unit;
 import net.sf.openrocket.unit.UnitGroup;
 import net.sf.openrocket.util.GUIUtil;
+import net.sf.openrocket.util.Named;
 import net.sf.openrocket.util.Prefs;
+import net.sf.openrocket.util.SimpleFileFilter;
+import net.sf.openrocket.util.Utils;
+
 
 public class PreferencesDialog extends JDialog {
 	private static final LogHelper log = Application.getLogger();
@@ -47,22 +54,29 @@ public class PreferencesDialog extends JDialog {
 	private final List<DefaultUnitSelector> unitSelectors = new ArrayList<DefaultUnitSelector>();
 	
 	private File defaultDirectory = null;
+	private static final Translator trans = Application.getTranslator();
 	
-	private PreferencesDialog() {
-		super((Window) null, "Preferences", Dialog.ModalityType.APPLICATION_MODAL);
+	private PreferencesDialog(Window parent) {
+		//// Preferences
+		super(parent, trans.get("pref.dlg.title.Preferences"), Dialog.ModalityType.APPLICATION_MODAL);
 		
 		JPanel panel = new JPanel(new MigLayout("fill, gap unrel", "[grow]", "[grow][]"));
 		
 		JTabbedPane tabbedPane = new JTabbedPane();
 		panel.add(tabbedPane, "grow, wrap");
 		
-
-		tabbedPane.addTab("Units", null, unitsPane(), "Default units");
-		tabbedPane.addTab("Materials", null, new MaterialEditPanel(), "Custom materials");
-		tabbedPane.addTab("Options", null, optionsPane(), "Miscellaneous options");
+		//// Units and Default units
+		tabbedPane.addTab(trans.get("pref.dlg.tab.Units"), null, unitsPane(),
+				trans.get("pref.dlg.tab.Defaultunits"));
+		//// Materials and Custom materials
+		tabbedPane.addTab(trans.get("pref.dlg.tab.Materials"), null, new MaterialEditPanel(),
+				trans.get("pref.dlg.tab.Custommaterials"));
+		//// Options and Miscellaneous options
+		tabbedPane.addTab(trans.get("pref.dlg.tab.Options"), null, optionsPane(),
+				trans.get("pref.dlg.tab.Miscellaneousoptions"));
 		
-
-		JButton close = new JButton("Close");
+		//// Close button
+		JButton close = new JButton(trans.get("dlg.but.close"));
 		close.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent arg0) {
@@ -91,16 +105,55 @@ public class PreferencesDialog extends JDialog {
 		JPanel panel = new JPanel(new MigLayout("fillx, ins 30lp n n n"));
 		
 
-		panel.add(new JLabel("Position to insert new body components:"), "gapright para");
-		panel.add(new JComboBox(new PrefChoiseSelector(Prefs.BODY_COMPONENT_INSERT_POSITION_KEY,
-				"Always ask", "Insert in middle", "Add to end")), "wrap para, growx, sg combos");
+		//// Language selector
+		Locale userLocale = Prefs.getUserLocale();
+		List<Named<Locale>> locales = new ArrayList<Named<Locale>>();
+		for (Locale l : Prefs.getSupportedLocales()) {
+			locales.add(new Named<Locale>(l, l.getDisplayLanguage()));
+		}
+		Collections.sort(locales);
+		locales.add(0, new Named<Locale>(null, trans.get("languages.default")));
 		
-		panel.add(new JLabel("Confirm deletion of simulations:"));
-		panel.add(new JComboBox(new PrefBooleanSelector(Prefs.CONFIRM_DELETE_SIMULATION,
-				"Delete", "Confirm", true)), "wrap 40lp, growx, sg combos");
+		final JComboBox languageCombo = new JComboBox(locales.toArray());
+		for (int i = 0; i < locales.size(); i++) {
+			if (Utils.equals(userLocale, locales.get(i).get())) {
+				languageCombo.setSelectedIndex(i);
+			}
+		}
+		languageCombo.addActionListener(new ActionListener() {
+			@Override
+			@SuppressWarnings("unchecked")
+			public void actionPerformed(ActionEvent e) {
+				Named<Locale> selection = (Named<Locale>) languageCombo.getSelectedItem();
+				Prefs.setUserLocale(selection.get());
+			}
+		});
+		panel.add(new JLabel(trans.get("lbl.language")), "gapright para");
+		panel.add(languageCombo, "wrap rel, growx, sg combos");
+		
+		panel.add(new StyledLabel(trans.get("PreferencesDialog.lbl.languageEffect"), -3, Style.ITALIC), "span, wrap para*2");
 		
 
-		panel.add(new JLabel("User-defined thrust curves:"), "spanx, wrap");
+		//// Position to insert new body components:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Positiontoinsert")), "gapright para");
+		panel.add(new JComboBox(new PrefChoiseSelector(Prefs.BODY_COMPONENT_INSERT_POSITION_KEY,
+				//// Always ask
+				//// Insert in middle
+				//// Add to end
+				trans.get("pref.dlg.PrefChoiseSelector1"),
+				trans.get("pref.dlg.PrefChoiseSelector2"),
+				trans.get("pref.dlg.PrefChoiseSelector3"))), "wrap para, growx, sg combos");
+		
+		//// Confirm deletion of simulations:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Confirmdeletion")));
+		panel.add(new JComboBox(new PrefBooleanSelector(Prefs.CONFIRM_DELETE_SIMULATION,
+				//// Delete
+				//// Confirm
+				trans.get("pref.dlg.PrefBooleanSelector1"),
+				trans.get("pref.dlg.PrefBooleanSelector2"), true)), "wrap 40lp, growx, sg combos");
+		
+		//// User-defined thrust curves:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.User-definedthrust")), "spanx, wrap");
 		final JTextField field = new JTextField();
 		List<File> files = Prefs.getUserThrustCurveFiles();
 		String str = "";
@@ -141,19 +194,26 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(field, "w 100px, gapright unrel, spanx, growx, split");
 		
-		JButton button = new JButton("Add");
+		//// Add button
+		JButton button = new JButton(trans.get("pref.dlg.but.add"));
 		button.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
 				JFileChooser chooser = new JFileChooser();
-				SimpleFileFilter filter = new SimpleFileFilter("All thrust curve files (*.eng; *.rse; *.zip; directories)",
-						true, "eng", "rse", "zip");
+				SimpleFileFilter filter =
+						new SimpleFileFilter(
+								//// All thrust curve files (*.eng; *.rse; *.zip; directories)
+								trans.get("pref.dlg.Allthrustcurvefiles"),
+								true, "eng", "rse", "zip");
 				chooser.addChoosableFileFilter(filter);
-				chooser.addChoosableFileFilter(new SimpleFileFilter("RASP motor files (*.eng)",
+				//// RASP motor files (*.eng)
+				chooser.addChoosableFileFilter(new SimpleFileFilter(trans.get("pref.dlg.RASPfiles"),
 						true, "eng"));
-				chooser.addChoosableFileFilter(new SimpleFileFilter("RockSim engine files (*.rse)",
+				//// RockSim engine files (*.rse)
+				chooser.addChoosableFileFilter(new SimpleFileFilter(trans.get("pref.dlg.RockSimfiles"),
 						true, "rse"));
-				chooser.addChoosableFileFilter(new SimpleFileFilter("ZIP archives (*.zip)",
+				//// ZIP archives (*.zip)
+				chooser.addChoosableFileFilter(new SimpleFileFilter(trans.get("pref.dlg.ZIParchives"),
 						true, "zip"));
 				chooser.setFileFilter(filter);
 				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
@@ -161,7 +221,8 @@ public class PreferencesDialog extends JDialog {
 					chooser.setCurrentDirectory(defaultDirectory);
 				}
 				
-				int returnVal = chooser.showDialog(PreferencesDialog.this, "Add");
+				//// Add
+				int returnVal = chooser.showDialog(PreferencesDialog.this, trans.get("pref.dlg.Add"));
 				if (returnVal == JFileChooser.APPROVE_OPTION) {
 					log.user("Adding user thrust curve: " + chooser.getSelectedFile());
 					defaultDirectory = chooser.getCurrentDirectory();
@@ -176,7 +237,8 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(button, "gapright unrel");
 		
-		button = new JButton("Reset");
+		//// Reset button
+		button = new JButton(trans.get("pref.dlg.but.reset"));
 		
 		button.addActionListener(new ActionListener() {
 			@Override
@@ -188,16 +250,16 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(button, "wrap");
 		
-		DescriptionArea desc = new DescriptionArea("Add directories, RASP motor files (*.eng), " +
-				"RockSim engine files (*.rse) or ZIP archives separated by a semicolon (;) to load external " +
-				"thrust curves.  Changes will take effect the next time you start OpenRocket.", 3, -3, false);
+		//// Add directories, RASP motor files (*.eng), RockSim engine files (*.rse) or ZIP archives separated by a semicolon (;) to load external thrust curves.  Changes will take effect the next time you start OpenRocket.
+		DescriptionArea desc = new DescriptionArea(trans.get("pref.dlg.DescriptionArea.Adddirectories"), 3, -3, false);
 		desc.setBackground(getBackground());
 		panel.add(desc, "spanx, growx, wrap 40lp");
 		
 
 
-
-		final JCheckBox softwareUpdateBox = new JCheckBox("Check for software updates at startup");
+		//// Check for software updates at startup
+		final JCheckBox softwareUpdateBox =
+				new JCheckBox(trans.get("pref.dlg.checkbox.Checkupdates"));
 		softwareUpdateBox.setSelected(Prefs.getCheckUpdates());
 		softwareUpdateBox.addActionListener(new ActionListener() {
 			@Override
@@ -207,8 +269,10 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(softwareUpdateBox);
 		
-		button = new JButton("Check now");
-		button.setToolTipText("Check for software updates now");
+		//// Check now button
+		button = new JButton(trans.get("pref.dlg.but.checknow"));
+		//// Check for software updates now
+		button.setToolTipText(trans.get("pref.dlg.ttip.Checkupdatesnow"));
 		button.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
@@ -225,100 +289,118 @@ public class PreferencesDialog extends JDialog {
 		JPanel panel = new JPanel(new MigLayout("", "[][]40lp[][]"));
 		JComboBox combo;
 		
-		panel.add(new JLabel("Select your preferred units:"), "span, wrap paragraph");
+		//// Select your preferred units:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Selectprefunits")), "span, wrap paragraph");
 		
 
-		panel.add(new JLabel("Rocket dimensions:"));
+		//// Rocket dimensions:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Rocketdimensions")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_LENGTH));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Line density:"));
+		//// Line density:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Linedensity")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_DENSITY_LINE));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Motor dimensions:"));
+		//// Motor dimensions:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Motordimensions")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_MOTOR_DIMENSIONS));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Surface density:"));
+		//// Surface density:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Surfacedensity")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_DENSITY_SURFACE));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Distance:"));
+		//// Distance:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Distance")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_DISTANCE));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Bulk density::"));
+		//// Bulk density::
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Bulkdensity")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_DENSITY_BULK));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Velocity:"));
+		//// Velocity:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Velocity")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_VELOCITY));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Surface roughness:"));
+		//// Surface roughness:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Surfaceroughness")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_ROUGHNESS));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Acceleration:"));
+		//// Acceleration:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Acceleration")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_ACCELERATION));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Area:"));
+		//// Area:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Area")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_AREA));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Mass:"));
+		//// Mass:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Mass")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_MASS));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Angle:"));
+		//// Angle:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Angle")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_ANGLE));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Force:"));
+		//// Force:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Force")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_FORCE));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Roll rate:"));
+		//// Roll rate:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Rollrate")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_ROLL));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Total impulse:"));
+		//// Total impulse:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Totalimpulse")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_IMPULSE));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Temperature:"));
+		//// Temperature:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Temperature")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_TEMPERATURE));
 		panel.add(combo, "sizegroup boxes, wrap");
 		
 
-
-		panel.add(new JLabel("Stability:"));
-		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_STABILITY));
+		//// Moment of inertia:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Momentofinertia")));
+		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_INERTIA));
 		panel.add(combo, "sizegroup boxes");
 		
-		panel.add(new JLabel("Pressure:"));
+		//// Pressure:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Pressure")));
 		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_PRESSURE));
+		panel.add(combo, "sizegroup boxes, wrap");
+		
+
+		//// Stability:
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Stability")));
+		combo = new JComboBox(new DefaultUnitSelector(UnitGroup.UNITS_STABILITY));
 		panel.add(combo, "sizegroup boxes, wrap para");
 		
 
 
-		JButton button = new JButton("Default metric");
+		//// Default metric button
+		JButton button = new JButton(trans.get("pref.dlg.but.defaultmetric"));
 		button.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
@@ -329,7 +411,8 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(button, "spanx, split 2, grow");
 		
-		button = new JButton("Default imperial");
+		//// Default imperial button
+		button = new JButton(trans.get("pref.dlg.but.defaultimperial"));
 		button.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
@@ -340,8 +423,9 @@ public class PreferencesDialog extends JDialog {
 		});
 		panel.add(button, "grow, wrap para");
 		
-
-		panel.add(new StyledLabel("The effects will take place the next time you open a window.", -2),
+		//// The effects will take place the next time you open a window.
+		panel.add(new StyledLabel(
+				trans.get("pref.dlg.lbl.effect1"), -2, Style.ITALIC),
 				"spanx, wrap");
 		
 
@@ -514,13 +598,15 @@ public class PreferencesDialog extends JDialog {
 		final JDialog dialog = new JDialog(this, ModalityType.APPLICATION_MODAL);
 		JPanel panel = new JPanel(new MigLayout());
 		
-		panel.add(new JLabel("Checking for updates..."), "wrap");
+		//// Checking for updates...
+		panel.add(new JLabel(trans.get("pref.dlg.lbl.Checkingupdates")), "wrap");
 		
 		JProgressBar bar = new JProgressBar();
 		bar.setIndeterminate(true);
 		panel.add(bar, "growx, wrap para");
 		
-		JButton cancel = new JButton("Cancel");
+		//// Cancel button
+		JButton cancel = new JButton(trans.get("dlg.but.cancel"));
 		cancel.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
@@ -558,14 +644,18 @@ public class PreferencesDialog extends JDialog {
 		UpdateInfo info = retriever.getUpdateInfo();
 		if (info == null) {
 			JOptionPane.showMessageDialog(this,
-					"An error occurred while communicating with the server.",
-					"Unable to retrieve update information", JOptionPane.WARNING_MESSAGE, null);
+					//// An error occurred while communicating with the server.
+					trans.get("pref.dlg.lbl.msg1"),
+					//// Unable to retrieve update information
+					trans.get("pref.dlg.lbl.msg2"), JOptionPane.WARNING_MESSAGE, null);
 		} else if (info.getLatestVersion() == null ||
 				info.getLatestVersion().equals("") ||
 				Prefs.getVersion().equalsIgnoreCase(info.getLatestVersion())) {
 			JOptionPane.showMessageDialog(this,
-					"You are running the latest version of OpenRocket.",
-					"No updates available", JOptionPane.INFORMATION_MESSAGE, null);
+					//// You are running the latest version of OpenRocket.
+					trans.get("pref.dlg.lbl.msg3"),
+					//// No updates available
+					trans.get("pref.dlg.lbl.msg4"), JOptionPane.INFORMATION_MESSAGE, null);
 		} else {
 			UpdateInfoDialog infoDialog = new UpdateInfoDialog(info);
 			infoDialog.setVisible(true);
@@ -583,11 +673,11 @@ public class PreferencesDialog extends JDialog {
 	
 	private static PreferencesDialog dialog = null;
 	
-	public static void showPreferences() {
+	public static void showPreferences(Window parent) {
 		if (dialog != null) {
 			dialog.dispose();
 		}
-		dialog = new PreferencesDialog();
+		dialog = new PreferencesDialog(parent);
 		dialog.setVisible(true);
 	}
 	
