@@ -6,8 +6,6 @@ import java.awt.Toolkit;
 import java.awt.Window;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.awt.event.ComponentAdapter;
-import java.awt.event.ComponentEvent;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
@@ -30,6 +28,7 @@ import java.util.List;
 import java.util.concurrent.ExecutionException;
 
 import javax.swing.Action;
+import javax.swing.BorderFactory;
 import javax.swing.InputMap;
 import javax.swing.JButton;
 import javax.swing.JComponent;
@@ -40,7 +39,9 @@ import javax.swing.JMenuBar;
 import javax.swing.JMenuItem;
 import javax.swing.JOptionPane;
 import javax.swing.JPanel;
+import javax.swing.JPopupMenu;
 import javax.swing.JScrollPane;
+import javax.swing.JSpinner;
 import javax.swing.JSplitPane;
 import javax.swing.JTabbedPane;
 import javax.swing.JTextField;
@@ -48,6 +49,7 @@ import javax.swing.KeyStroke;
 import javax.swing.ListSelectionModel;
 import javax.swing.ScrollPaneConstants;
 import javax.swing.SwingUtilities;
+import javax.swing.border.BevelBorder;
 import javax.swing.border.TitledBorder;
 import javax.swing.event.TreeSelectionEvent;
 import javax.swing.event.TreeSelectionListener;
@@ -80,7 +82,6 @@ import net.sf.openrocket.gui.dialogs.WarningDialog;
 import net.sf.openrocket.gui.dialogs.optimization.GeneralOptimizationDialog;
 import net.sf.openrocket.gui.dialogs.preferences.PreferencesDialog;
 import net.sf.openrocket.gui.main.componenttree.ComponentTree;
-import net.sf.openrocket.gui.optimization.OptimizationTestDialog;
 import net.sf.openrocket.gui.scalefigure.RocketPanel;
 import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.logging.LogHelper;
@@ -125,9 +126,6 @@ public class BasicFrame extends JFrame {
 	private static final ArrayList<BasicFrame> frames = new ArrayList<BasicFrame>();
 	
 
-
-
-
 	/**
 	 * Whether "New" and "Open" should replace this frame.
 	 * Should be set to false on the first rocket modification.
@@ -233,19 +231,16 @@ public class BasicFrame extends JFrame {
 		setTitle();
 		this.pack();
 		
-		Dimension size = Prefs.getWindowSize(this.getClass());
-		if (size == null) {
-			size = Toolkit.getDefaultToolkit().getScreenSize();
-			size.width = size.width * 9 / 10;
-			size.height = size.height * 9 / 10;
-		}
+
+		// Set initial window size
+		Dimension size = Toolkit.getDefaultToolkit().getScreenSize();
+		size.width = size.width * 9 / 10;
+		size.height = size.height * 9 / 10;
 		this.setSize(size);
-		this.addComponentListener(new ComponentAdapter() {
-			@Override
-			public void componentResized(ComponentEvent e) {
-				Prefs.setWindowSize(BasicFrame.this.getClass(), BasicFrame.this.getSize());
-			}
-		});
+		
+		// Remember changed size
+		GUIUtil.rememberWindowSize(this);
+		
 		this.setLocationByPlatform(true);
 		
 		GUIUtil.setWindowIcons(this);
@@ -259,8 +254,8 @@ public class BasicFrame extends JFrame {
 				closeAction();
 			}
 		});
-		frames.add(this);
 		
+		frames.add(this);
 		log.debug("BasicFrame instantiation complete");
 	}
 	
@@ -367,8 +362,8 @@ public class BasicFrame extends JFrame {
 		scroll.setBorder(null);
 		scroll.setViewportBorder(null);
 		
-		TitledBorder border = new TitledBorder(trans.get("BasicFrame.title.Addnewcomp"));
-		border.setTitleFont(border.getTitleFont().deriveFont(Font.BOLD));
+		TitledBorder border = BorderFactory.createTitledBorder(trans.get("BasicFrame.title.Addnewcomp"));
+		GUIUtil.changeFontStyle(border, Font.BOLD);
 		scroll.setBorder(border);
 		
 		panel.add(scroll, "grow");
@@ -648,6 +643,19 @@ public class BasicFrame extends JFrame {
 		menu.add(item);
 		
 
+		item = new JMenuItem(trans.get("main.menu.analyze.optimization"), KeyEvent.VK_O);
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.analyze.optimization.desc"));
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("Rocket optimization selected");
+				new GeneralOptimizationDialog(document, BasicFrame.this).setVisible(true);
+			}
+		});
+		menu.add(item);
+		
+
+
 		////  Debug
 		// (shown if openrocket.debug.menu is defined)
 		if (System.getProperty("openrocket.debug.menu") != null) {
@@ -660,14 +668,13 @@ public class BasicFrame extends JFrame {
 		
 		menu = new JMenu(trans.get("main.menu.help"));
 		menu.setMnemonic(KeyEvent.VK_H);
-		//// Information about OpenRocket
 		menu.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.desc"));
 		menubar.add(menu);
 		
 
 		//// License
 		item = new JMenuItem(trans.get("main.menu.help.license"), KeyEvent.VK_L);
-		//// OpenRocket license information
+		item.setIcon(Icons.HELP_LICENSE);
 		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.license.desc"));
 		item.addActionListener(new ActionListener() {
 			@Override
@@ -682,7 +689,7 @@ public class BasicFrame extends JFrame {
 		
 		//// Bug report
 		item = new JMenuItem(trans.get("main.menu.help.bugReport"), KeyEvent.VK_B);
-		//// Information about reporting bugs in OpenRocket
+		item.setIcon(Icons.HELP_BUG_REPORT);
 		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.bugReport.desc"));
 		item.addActionListener(new ActionListener() {
 			@Override
@@ -695,7 +702,7 @@ public class BasicFrame extends JFrame {
 		
 		//// Debug log
 		item = new JMenuItem(trans.get("main.menu.help.debugLog"));
-		//// View the OpenRocket debug log
+		item.setIcon(Icons.HELP_DEBUG_LOG);
 		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.debugLog.desc"));
 		item.addActionListener(new ActionListener() {
 			@Override
@@ -710,7 +717,7 @@ public class BasicFrame extends JFrame {
 		
 		//// About
 		item = new JMenuItem(trans.get("main.menu.help.about"), KeyEvent.VK_A);
-		//// About OpenRocket
+		item.setIcon(Icons.HELP_ABOUT);
 		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.about.desc"));
 		item.addActionListener(new ActionListener() {
 			@Override
@@ -951,25 +958,28 @@ public class BasicFrame extends JFrame {
 		menu.add(item);
 		
 
-		item = new JMenuItem("General optimization test");
+		menu.addSeparator();
+		
+
+		item = new JMenuItem("Test popup");
 		item.addActionListener(new ActionListener() {
 			@Override
 			public void actionPerformed(ActionEvent e) {
-				new GeneralOptimizationDialog(document, BasicFrame.this).setVisible(true);
+				log.user("Test popup selected");
+				JPanel panel = new JPanel();
+				panel.add(new JTextField(40));
+				panel.add(new JSpinner());
+				JPopupMenu popup = new JPopupMenu();
+				popup.setBorder(BorderFactory.createBevelBorder(BevelBorder.RAISED));
+				popup.add(panel);
+				popup.show(BasicFrame.this, -50, 100);
 			}
 		});
 		menu.add(item);
 		
 
-		item = new JMenuItem("Optimization test");
-		item.addActionListener(new ActionListener() {
-			@Override
-			public void actionPerformed(ActionEvent e) {
-				new OptimizationTestDialog(BasicFrame.this, document).setVisible(true);
-			}
-		});
-		menu.add(item);
-		
+
+
 		return menu;
 	}
 	
@@ -1013,6 +1023,10 @@ public class BasicFrame extends JFrame {
 				
 				// Close previous window if replacing
 				if (replaceable && document.isSaved()) {
+					// We are replacing the frame, make new window have current location
+					BasicFrame newFrame = frames.get(frames.size() - 1);
+					newFrame.setLocation(this.getLocation());
+					
 					log.info("Closing window because it is replaceable");
 					closeAction();
 					replaceable = false;
@@ -1194,6 +1208,7 @@ public class BasicFrame extends JFrame {
 		doc.setFile(file);
 		doc.setSaved(true);
 		
+
 		// Open the frame
 		log.debug("Opening new frame with the document");
 		BasicFrame frame = new BasicFrame(doc);
@@ -1370,13 +1385,6 @@ public class BasicFrame extends JFrame {
 	 * 
 	 */
 	public void printAction() {
-		if (!Prefs.getBoolean("printing.experimental.communicated", false)) {
-			log.info("Showing printing is experimental warning to the user");
-			JOptionPane.showMessageDialog(this, "Printing is an currently an experimental feature " +
-					"and might not fully work on all platforms",
-					"Experimental feature", JOptionPane.WARNING_MESSAGE);
-			Prefs.putBoolean("printing.experimental.communicated", true);
-		}
 		new PrintDialog(this, document).setVisible(true);
 	}
 	
