@@ -1,6 +1,35 @@
 package net.sf.openrocket.gui.scalefigure;
 
 
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.Point;
+import java.awt.event.ActionEvent;
+import java.awt.event.InputEvent;
+import java.awt.event.MouseEvent;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
+import java.util.concurrent.Executor;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ThreadFactory;
+
+import javax.swing.AbstractAction;
+import javax.swing.Action;
+import javax.swing.JComboBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JSlider;
+import javax.swing.JToggleButton;
+import javax.swing.JViewport;
+import javax.swing.SwingUtilities;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+import javax.swing.event.TreeSelectionEvent;
+import javax.swing.event.TreeSelectionListener;
+import javax.swing.tree.TreePath;
+import javax.swing.tree.TreeSelectionModel;
+
 import net.miginfocom.swing.MigLayout;
 import net.sf.openrocket.aerodynamics.AerodynamicCalculator;
 import net.sf.openrocket.aerodynamics.BarrowmanCalculator;
@@ -40,34 +69,6 @@ import net.sf.openrocket.util.Coordinate;
 import net.sf.openrocket.util.MathUtil;
 import net.sf.openrocket.util.Prefs;
 
-import javax.swing.AbstractAction;
-import javax.swing.Action;
-import javax.swing.JComboBox;
-import javax.swing.JLabel;
-import javax.swing.JPanel;
-import javax.swing.JSlider;
-import javax.swing.JToggleButton;
-import javax.swing.JViewport;
-import javax.swing.SwingUtilities;
-import javax.swing.event.ChangeEvent;
-import javax.swing.event.ChangeListener;
-import javax.swing.event.TreeSelectionEvent;
-import javax.swing.event.TreeSelectionListener;
-import javax.swing.tree.TreePath;
-import javax.swing.tree.TreeSelectionModel;
-import java.awt.Dimension;
-import java.awt.Font;
-import java.awt.Point;
-import java.awt.event.ActionEvent;
-import java.awt.event.InputEvent;
-import java.awt.event.MouseEvent;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.List;
-import java.util.concurrent.Executor;
-import java.util.concurrent.Executors;
-import java.util.concurrent.ThreadFactory;
-
 /**
  * A JPanel that contains a RocketFigure and buttons to manipulate the figure. 
  * 
@@ -108,7 +109,6 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 	
 
 	private SimulationWorker backgroundSimulationWorker = null;
-	private boolean dirty = false;
 	
 	private List<ChangeListener> listeners = new ArrayList<ChangeListener>();
 	
@@ -241,12 +241,13 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 		add(new BasicSlider(theta.getSliderModel(0, 2 * Math.PI), JSlider.VERTICAL, true),
 				"ax 50%, wrap, width " + (d.width + 6) + "px:null:null, growy");
 		
-		
+
 		//// <html>Click to select &nbsp;&nbsp; Shift+click to select other &nbsp;&nbsp; Double-click to edit &nbsp;&nbsp; Click+drag to move
 		infoMessage = new JLabel(trans.get("RocketPanel.lbl.infoMessage"));
 		infoMessage.setFont(new Font("Sans Serif", Font.PLAIN, 9));
 		add(infoMessage, "skip, span, gapleft 25, wrap");
 		
+
 		addExtras();
 	}
 	
@@ -263,35 +264,35 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 	public Configuration getConfiguration() {
 		return configuration;
 	}
-
-    /**
-     * Get the center of pressure figure element.
-     * 
-     * @return center of pressure info
-     */
-    public Caret getExtraCP () {
-        return extraCP;
-    }
-
-    /**
-     * Get the center of gravity figure element.
-     * 
-     * @return center of gravity info
-     */
-    public Caret getExtraCG () {
-        return extraCG;
-    }
-
-    /**
-     * Get the extra text figure element.
-     * 
-     * @return extra text that contains info about the rocket design
-     */
-    public RocketInfo getExtraText () {
-        return extraText;
-    }
-
-    public void setSelectionModel(TreeSelectionModel m) {
+	
+	/**
+	 * Get the center of pressure figure element.
+	 * 
+	 * @return center of pressure info
+	 */
+	public Caret getExtraCP() {
+		return extraCP;
+	}
+	
+	/**
+	 * Get the center of gravity figure element.
+	 * 
+	 * @return center of gravity info
+	 */
+	public Caret getExtraCG() {
+		return extraCG;
+	}
+	
+	/**
+	 * Get the extra text figure element.
+	 * 
+	 * @return extra text that contains info about the rocket design
+	 */
+	public RocketInfo getExtraText() {
+		return extraText;
+	}
+	
+	public void setSelectionModel(TreeSelectionModel m) {
 		if (selectionModel != null) {
 			selectionModel.removeTreeSelectionListener(this);
 		}
@@ -592,7 +593,7 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 		
 		Rocket duplicate = (Rocket) configuration.getRocket().copy();
 		Simulation simulation = Prefs.getBackgroundSimulation(duplicate);
-		simulation.getConditions().setMotorConfigurationID(
+		simulation.getOptions().setMotorConfigurationID(
 				configuration.getMotorConfigurationID());
 		
 		backgroundSimulationWorker = new BackgroundSimulationWorker(simulation);
