@@ -4,6 +4,7 @@ import java.util.List;
 
 import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.material.Material;
+import net.sf.openrocket.material.Material.Type;
 import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.unit.UnitGroup;
 import net.sf.openrocket.util.Prefs;
@@ -111,7 +112,9 @@ public abstract class ExternalComponent extends RocketComponent {
 		if (material.equals(mat))
 			return;
 		material = mat;
+		clearPreset();
 		fireComponentChangeEvent(ComponentChangeEvent.MASS_CHANGE);
+		clearPreset();
 	}
 	
 	public Finish getFinish() {
@@ -126,6 +129,31 @@ public abstract class ExternalComponent extends RocketComponent {
 	}
 	
 	
+	@Override
+	protected void loadFromPreset(RocketComponent preset) {
+		super.loadFromPreset(preset);
+		
+		// Surface finish is left unchanged
+		
+		ExternalComponent c = (ExternalComponent) preset;
+		
+		Material mat = c.getMaterial();
+		if (c.isMassOverridden()) {
+			double mass = c.getOverrideMass();
+			double volume = getComponentVolume();
+			double density;
+			if (volume > 0.00001) {
+				density = mass / volume;
+			} else {
+				density = 1000;
+			}
+			mat = Material.newMaterial(Type.BULK, mat.getName(), density, true);
+		}
+		
+		setMaterial(mat);
+	}
+	
+	
 	@Override
 	protected List<RocketComponent> copyFrom(RocketComponent c) {
 		ExternalComponent src = (ExternalComponent) c;
