@@ -1,13 +1,20 @@
 package net.sf.openrocket.rocketcomponent;
 
-import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
 
+import net.sf.openrocket.l10n.Translator;
+import net.sf.openrocket.logging.LogHelper;
+import net.sf.openrocket.startup.Application;
+import net.sf.openrocket.util.ArrayList;
 import net.sf.openrocket.util.BugException;
 import net.sf.openrocket.util.Coordinate;
 
 
 public class FreeformFinSet extends FinSet {
+	private static final LogHelper log = Application.getLogger();
+	private static final Translator trans = Application.getTranslator();
 	
 	private ArrayList<Coordinate> points = new ArrayList<Coordinate>();
 	
@@ -29,7 +36,7 @@ public class FreeformFinSet extends FinSet {
 	public FreeformFinSet(FinSet finset) {
 		Coordinate[] finpoints = finset.getFinPoints();
 		this.copyFrom(finset);
-		
+
 		points.clear();
 		for (Coordinate c: finpoints) {
 			points.add(c);
@@ -45,13 +52,15 @@ public class FreeformFinSet extends FinSet {
 	 * inserted in its stead.
 	 * <p>
 	 * The specified fin set should not be used after the call!
-	 * 
+	 *
 	 * @param finset	the fin set to convert.
 	 * @return			the new freeform fin set.
 	 */
 	public static FreeformFinSet convertFinSet(FinSet finset) {
+		log.info("Converting " + finset.getComponentName() + " into freeform fin set");
 		final RocketComponent root = finset.getRoot();
 		FreeformFinSet freeform;
+		List<RocketComponent> toInvalidate = Collections.emptyList();
 		
 		try {
 			if (root instanceof Rocket) {
@@ -80,7 +89,7 @@ public class FreeformFinSet extends FinSet {
 			}
 			
 			// Copy component attributes
-			freeform.copyFrom(finset);
+			toInvalidate = freeform.copyFrom(finset);
 			
 			// Set name
 			final String componentTypeName = finset.getComponentName();
@@ -100,6 +109,10 @@ public class FreeformFinSet extends FinSet {
 			if (root instanceof Rocket) {
 				((Rocket) root).thaw();
 			}
+			// Invalidate components after events have been fired
+			for (RocketComponent c : toInvalidate) {
+				c.invalidate();
+			}
 		}
 		return freeform;
 	}
@@ -109,7 +122,7 @@ public class FreeformFinSet extends FinSet {
 	/**
 	 * Add a fin point between indices <code>index-1</code> and <code>index</code>.
 	 * The point is placed at the midpoint of the current segment.
-	 * 
+	 *
 	 * @param index   the fin point before which to add the new point.
 	 */
 	public void addPoint(int index) {
@@ -130,17 +143,16 @@ public class FreeformFinSet extends FinSet {
 	 * Remove the fin point with the given index.  The first and last fin points
 	 * cannot be removed, and will cause an <code>IllegalFinPointException</code>
 	 * if attempted.
-	 * 
+	 *
 	 * @param index   the fin point index to remove
 	 * @throws IllegalFinPointException if removing would result in invalid fin planform
 	 */
-	@SuppressWarnings("unchecked")
 	public void removePoint(int index) throws IllegalFinPointException {
 		if (index == 0 || index == points.size() - 1) {
 			throw new IllegalFinPointException("cannot remove first or last point");
 		}
 		
-		ArrayList<Coordinate> copy = (ArrayList<Coordinate>) this.points.clone();
+		ArrayList<Coordinate> copy = this.points.clone();
 		copy.remove(index);
 		validate(copy);
 		this.points = copy;
@@ -170,13 +182,13 @@ public class FreeformFinSet extends FinSet {
 	 * Set the point at position <code>i</code> to coordinates (x,y).
 	 * <p>
 	 * Note that this method enforces basic fin shape restrictions (non-negative y,
-	 * first and last point locations) silently, but throws an 
+	 * first and last point locations) silently, but throws an
 	 * <code>IllegalFinPointException</code> if the point causes fin segments to
 	 * intersect.
 	 * <p>
 	 * Moving of the first point in the X-axis is allowed, but this actually moves
 	 * all of the other points the corresponding distance back.
-	 * 
+	 *
 	 * @param index	the point index to modify.
 	 * @param x		the x-coordinate.
 	 * @param y		the y-coordinate.
@@ -293,33 +305,32 @@ public class FreeformFinSet extends FinSet {
 	
 	@Override
 	public String getComponentName() {
-		return "Freeform fin set";
+		//// Freeform fin set
+		return trans.get("FreeformFinSet.FreeformFinSet");
 	}
 	
 	
-	@SuppressWarnings("unchecked")
 	@Override
 	protected RocketComponent copyWithOriginalID() {
 		RocketComponent c = super.copyWithOriginalID();
-		((FreeformFinSet) c).points = (ArrayList<Coordinate>) this.points.clone();
+		((FreeformFinSet) c).points = this.points.clone();
 		return c;
 	}
 	
-	
-	private void validate(ArrayList<Coordinate> points) throws IllegalFinPointException {
-		final int n = points.size();
-		if (points.get(0).x != 0 || points.get(0).y != 0 ||
-				points.get(n - 1).x < 0 || points.get(n - 1).y != 0) {
+	private void validate(ArrayList<Coordinate> pts) throws IllegalFinPointException {
+		final int n = pts.size();
+		if (pts.get(0).x != 0 || pts.get(0).y != 0 ||
+				pts.get(n - 1).x < 0 || pts.get(n - 1).y != 0) {
 			throw new IllegalFinPointException("Start or end point illegal.");
 		}
 		for (int i = 0; i < n - 1; i++) {
 			for (int j = i + 2; j < n - 1; j++) {
-				if (intersects(points.get(i).x, points.get(i).y, points.get(i + 1).x, points.get(i + 1).y,
-								points.get(j).x, points.get(j).y, points.get(j + 1).x, points.get(j + 1).y)) {
+				if (intersects(pts.get(i).x, pts.get(i).y, pts.get(i + 1).x, pts.get(i + 1).y,
+								pts.get(j).x, pts.get(j).y, pts.get(j + 1).x, pts.get(j + 1).y)) {
 					throw new IllegalFinPointException("segments intersect");
 				}
 			}
-			if (points.get(i).z != 0) {
+			if (pts.get(i).z != 0) {
 				throw new IllegalFinPointException("z-coordinate not zero");
 			}
 		}
