@@ -1,17 +1,8 @@
 package net.sf.openrocket.rocketcomponent;
 
-import java.awt.Color;
-import java.util.ArrayDeque;
-import java.util.Collection;
-import java.util.Deque;
-import java.util.Iterator;
-import java.util.List;
-import java.util.NoSuchElementException;
-
-import javax.swing.event.ChangeListener;
-
 import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.logging.LogHelper;
+import net.sf.openrocket.preset.ComponentPreset;
 import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.util.ArrayList;
 import net.sf.openrocket.util.BugException;
@@ -23,6 +14,15 @@ import net.sf.openrocket.util.MathUtil;
 import net.sf.openrocket.util.SafetyMutex;
 import net.sf.openrocket.util.UniqueID;
 
+import javax.swing.event.ChangeListener;
+import java.awt.*;
+import java.util.ArrayDeque;
+import java.util.Collection;
+import java.util.Deque;
+import java.util.Iterator;
+import java.util.List;
+import java.util.NoSuchElementException;
+
 
 public abstract class RocketComponent implements ChangeSource, Cloneable, Iterable<RocketComponent> {
 	private static final LogHelper log = Application.getLogger();
@@ -123,6 +123,10 @@ public abstract class RocketComponent implements ChangeSource, Cloneable, Iterab
 	// Unique ID of the component
 	private String id = null;
 	
+	// Preset component this component is based upon
+	private ComponentPreset presetComponent = null;
+	
+
 	/**
 	 * Used to invalidate the component after calling {@link #copyFrom(RocketComponent)}.
 	 */
@@ -659,6 +663,92 @@ public abstract class RocketComponent implements ChangeSource, Cloneable, Iterab
 	
 	
 
+	/**
+	 * Return the preset component that this component is based upon.
+	 * 
+	 * @return	the preset component, or <code>null</code> if this is not based on a preset.
+	 */
+	public final ComponentPreset getPresetComponent() {
+		return presetComponent;
+	}
+	
+	/**
+	 * Set the preset component this component is based upon and load all of the 
+	 * preset values.
+	 * 
+	 * @param preset	the preset component to load, or <code>null</code> to clear the preset.
+	 */
+	public final void loadPreset(ComponentPreset preset) {
+		if (presetComponent == preset) {
+			return;
+		}
+		
+		if (preset == null) {
+			clearPreset();
+			return;
+		}
+		
+		if (preset.getComponentClass() != this.getClass()) {
+			throw new IllegalArgumentException("Attempting to load preset of type " + preset.getComponentClass()
+						+ " into component of type " + this.getClass());
+		}
+		
+		RocketComponent root = getRoot();
+		final Rocket rocket;
+		if (root instanceof Rocket) {
+			rocket = (Rocket) root;
+		} else {
+			rocket = null;
+		}
+		
+		try {
+			if (rocket != null) {
+				rocket.freeze();
+			}
+			
+			loadFromPreset(preset.getPrototype());
+			
+			this.presetComponent = preset;
+			fireComponentChangeEvent(ComponentChangeEvent.NONFUNCTIONAL_CHANGE);
+			
+		} finally {
+			if (rocket != null) {
+				rocket.thaw();
+			}
+		}
+	}
+	
+	
+	/**
+	 * Load component properties from the specified preset.  The preset is guaranteed
+	 * to be of the correct type.
+	 * <p>
+	 * This method should fire the appropriate events related to the changes.  The rocket
+	 * is frozen by the caller, so the events will be automatically combined.
+	 * <p>
+	 * This method must FIRST perform the preset loading and THEN call super.loadFromPreset().
+	 * This is because mass setting requires the dimensions to be set beforehand.
+	 * 
+	 * @param preset	the preset to load from
+	 */
+	protected void loadFromPreset(RocketComponent preset) {
+		// No-op
+	}
+	
+	
+	/**
+	 * Clear the current component preset.  This does not affect the component properties
+	 * otherwise.
+	 */
+	public final void clearPreset() {
+		if (presetComponent == null)
+			return;
+		presetComponent = null;
+		fireComponentChangeEvent(ComponentChangeEvent.NONFUNCTIONAL_CHANGE);
+	}
+	
+	
+
 	/**
 	 * Returns the unique ID of the component.
 	 *
@@ -748,10 +838,42 @@ public abstract class RocketComponent implements ChangeSource, Cloneable, Iterab
 		this.relativePosition = position;
 		fireComponentChangeEvent(ComponentChangeEvent.BOTH_CHANGE);
 	}
-	
-	
 
 
+    /**
+     * Determine position relative to given position argument.  Note: This is a side-effect free method.  No state
+     * is modified.
+     *
+     * @param thePosition the relative position to be used as the basis for the computation
+     * @param relativeTo  the position is computed relative the the given component
+     *
+     * @return double position of the component relative to the parent, with respect to <code>position</code>
+     */
+    public double asPositionValue (Position thePosition, RocketComponent relativeTo) {
+        double result = this.position;
+        if (relativeTo != null) {
+            double thisPos = this.toRelative(Coordinate.NUL, relativeTo)[0].x;
+
+            switch (thePosition) {
+            case ABSOLUTE:
+                result = this.toAbsolute(Coordinate.NUL)[0].x;
+                break;
+            case TOP:
+                result = thisPos;
+                break;
+            case MIDDLE:
+                result = thisPos - (relativeTo.length - this.length) / 2;
+                break;
+            case BOTTOM:
+                result = thisPos - (relativeTo.length - this.length);
+                break;
+            default:
+                throw new BugException("Unknown position type: " + thePosition);
+            }
+        }
+        return result;
+    }
+
 	/**
 	 * Get the position value of the component.  The exact meaning of the value is
 	 * dependent on the current relative positioning.
