@@ -5,6 +5,8 @@ import net.sf.openrocket.models.atmosphere.AtmosphericConditions;
 import net.sf.openrocket.motor.MotorId;
 import net.sf.openrocket.motor.MotorInstance;
 import net.sf.openrocket.motor.MotorInstanceConfiguration;
+import net.sf.openrocket.rocketcomponent.Configuration;
+import net.sf.openrocket.rocketcomponent.RocketComponent;
 import net.sf.openrocket.simulation.exception.SimulationException;
 import net.sf.openrocket.simulation.listeners.SimulationListenerHelper;
 import net.sf.openrocket.util.BugException;
@@ -30,7 +32,7 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 		}
 		
 		// Compute conditions
-		double altitude = status.getRocketPosition().z + status.getSimulationConditions().getLaunchAltitude();
+		double altitude = status.getRocketPosition().z + status.getSimulationConditions().getLaunchSite().getAltitude();
 		conditions = status.getSimulationConditions().getAtmosphericModel().getConditions(altitude);
 		
 		// Call post-listener
@@ -61,7 +63,7 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 		}
 		
 		// Compute conditions
-		double altitude = status.getRocketPosition().z + status.getSimulationConditions().getLaunchAltitude();
+		double altitude = status.getRocketPosition().z + status.getSimulationConditions().getLaunchSite().getAltitude();
 		wind = status.getSimulationConditions().getWindModel().getWindVelocity(status.getSimulationTime(), altitude);
 		
 		// Call post-listener
@@ -91,8 +93,7 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 		}
 		
 		// Compute conditions
-		double altitude = status.getRocketPosition().z + status.getSimulationConditions().getLaunchAltitude();
-		gravity = status.getSimulationConditions().getGravityModel().getGravity(altitude);
+		gravity = status.getSimulationConditions().getGravityModel().getGravity(status.getRocketWorldPosition());
 		
 		// Call post-listener
 		gravity = SimulationListenerHelper.firePostGravityModel(status, gravity);
@@ -167,16 +168,20 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 			return thrust;
 		}
 		
+		Configuration configuration = status.getConfiguration();
+		
 		// Iterate over the motors and calculate combined thrust
-		MotorInstanceConfiguration configuration = status.getMotorConfiguration();
+		MotorInstanceConfiguration mic = status.getMotorConfiguration();
 		if (!stepMotors) {
-			configuration = configuration.clone();
+			mic = mic.clone();
 		}
-		configuration.step(status.getSimulationTime() + timestep, acceleration, atmosphericConditions);
+		mic.step(status.getSimulationTime() + timestep, acceleration, atmosphericConditions);
 		thrust = 0;
-		for (MotorId id : configuration.getMotorIDs()) {
-			MotorInstance motor = configuration.getMotorInstance(id);
-			thrust += motor.getThrust();
+		for (MotorId id : mic.getMotorIDs()) {
+			if (configuration.isComponentActive((RocketComponent) mic.getMotorMount(id))) {
+				MotorInstance motor = mic.getMotorInstance(id);
+				thrust += motor.getThrust();
+			}
 		}
 		
 		// Post-listeners
@@ -208,7 +213,7 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 	 */
 	protected void checkNaN(Coordinate c) {
 		if (c.isNaN()) {
-			throw new BugException("Simulation resulted in not-a-number (NaN) value, please report a bug.");
+			throw new BugException("Simulation resulted in not-a-number (NaN) value, please report a bug, c=" + c);
 		}
 	}
 	
@@ -221,7 +226,7 @@ public abstract class AbstractSimulationStepper implements SimulationStepper {
 	 */
 	protected void checkNaN(Quaternion q) {
 		if (q.isNaN()) {
-			throw new BugException("Simulation resulted in not-a-number (NaN) value, please report a bug.");
+			throw new BugException("Simulation resulted in not-a-number (NaN) value, please report a bug, q=" + q);
 		}
 	}
 }
